@@ -138,7 +138,7 @@ The generation of numbers for individual distributions is to left to the distrib
             offset += size
 
         if not self.sorted:
-            self.random_data = self.random_data[self.ordering]
+            self.random_data = self.random_data[argsort(self.ordering)]
 
         return self.random_data
 
