@@ -6,7 +6,7 @@ from scipy import stats
 
 DEFAULT_DISTRIBUTIONS = (UndefinedUncertainty, NoUncertainty, 
     LognormalUncertainty, NormalUncertainty, UniformUncertainty, 
-    TriangularUncertainty, BernoulliUncertainty)
+    TriangularUncertainty, BernoulliUncertainty, BetaUncertainty)
 
 CUSTOM_DISTRIBUTIONS = () # Don't forget to add trailing comma if needed
 
